@@ -1,6 +1,6 @@
 /*
  * This file is part of Gnome Subtitles.
- * Copyright (C) 2006-2009 Pedro Castro
+ * Copyright (C) 2006-2010 Pedro Castro
  *
  * Gnome Subtitles is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,11 +25,13 @@ using Gtk;
 using Mono.Unix;
 using SubLib.Core.Domain;
 using System;
+using System.Text;
 
 namespace GnomeSubtitles.Core {
 
 public class EventHandlers {
 
+
 	/* File Menu */
 	
 	public void OnFileNew (object o, EventArgs args) {
@@ -42,10 +44,18 @@ public class EventHandlers {
 	
 	public void OnFileSave (object o, EventArgs args) {
 		Base.Ui.Save();
+
+		if (Base.Document.IsTranslationLoaded && Base.Config.PrefsTranslationSaveAll) {
+			OnFileTranslationSave(o, args);
+		}
 	}
 	
 	public void OnFileSaveAs (object o, EventArgs args) {
 		Base.Ui.SaveAs();
+		
+		if (Base.Document.IsTranslationLoaded && Base.Config.PrefsTranslationSaveAll) {
+			OnFileTranslationSave(o, args);
+		}
 	}
 	
 	public void OnFileTranslationNew (object o, EventArgs args) {
@@ -83,8 +93,8 @@ public class EventHandlers {
     public void OnFileQuit (object o, EventArgs args) {
 		Base.Ui.Quit();
 	}
-	
-	
+
+
 	/* Edit Menu */
 	
 	public void OnEditUndo (object o, EventArgs args) {
@@ -142,6 +152,7 @@ public class EventHandlers {
 		Base.Dialogs.Get(typeof(PreferencesDialog)).Show();
 	}
 
+
 	/* View Menu */
 	
 	public void OnViewTimes (object o, EventArgs args) {
@@ -171,7 +182,8 @@ public class EventHandlers {
 		if ((o as RadioMenuItem).Active)
 			Base.Ui.Video.Overlay.ToShowText = false;
 	}
-	
+
+
 	/* Search Menu */
 	
 	public void OnSearchFind (object o, EventArgs args) {
@@ -189,7 +201,8 @@ public class EventHandlers {
 	public void OnSearchReplace (object o, EventArgs args) {
 		Base.Ui.View.Search.ShowReplace();
 	}
-	
+
+
 	/*	Timings Menu */
 	
 	public void OnTimingsInputFrameRate (object o, EventArgs args) {
@@ -219,8 +232,8 @@ public class EventHandlers {
 	public void OnTimingsSynchronize (object o, EventArgs args) {
 		Base.Dialogs.Get(typeof(TimingsSynchronizeDialog)).Show();
 	}
-	
-	
+
+
 	/* Video Menu */
 		
 	public void OnVideoOpen (object o, EventArgs args) {
@@ -273,7 +286,8 @@ public class EventHandlers {
 			Base.CommandManager.Execute(new VideoSetSubtitleEndCommand(frames));
 		}
 	}
-	
+
+
 	/* Tools Menu */
 		
 	public void OnToolsAutocheckSpelling (object o, EventArgs args) {
@@ -326,10 +340,26 @@ public class EventHandlers {
     }
 
 
-		/*	Subtitle View	*/
+	/* Subtitle Area */
+
+	public void OnSubtitleAreaDragDataReceived (object o, DragDataReceivedArgs args) {
+		string uriString = Encoding.UTF8.GetString(args.SelectionData.Data);
+		bool success = false;
+		Uri fileUri;
+
+		if (Uri.TryCreate(uriString, UriKind.Absolute, out fileUri) && (args.Info == DragDrop.DragDropTargetUriList)) {
+			Base.Ui.Open(fileUri.AbsolutePath);
+			success = true;
+		}
+
+		Gtk.Drag.Finish(args.Context, success, false, args.Time);
+	}
+
+
+	/*	Subtitle View	*/
     
     public void OnRowActivated (object o, RowActivatedArgs args) {
-    	Base.Ui.Video.SeekToSelection();
+    	Base.Ui.Video.SeekToPath(args.Path);
     }
     
     public void OnSubtitleViewKeyPressed (object o, KeyPressEventArgs args) {
@@ -340,6 +370,22 @@ public class EventHandlers {
 			OnEditInsertSubtitleAfter(o, EventArgs.Empty);
     }
 
+
+	/* Video Area */
+
+	public void OnVideoAreaDragDataReceived (object o, DragDataReceivedArgs args) {
+		string uriString = Encoding.UTF8.GetString(args.SelectionData.Data);
+		bool success = false;
+		Uri fileUri;
+
+		if (Uri.TryCreate(uriString, UriKind.Absolute, out fileUri) && (args.Info == DragDrop.DragDropTargetUriList)) {
+			Base.OpenVideo(fileUri);
+			success = true;
+		}
+
+		Gtk.Drag.Finish(args.Context, success, false, args.Time);
+	}
+
 }
 
 }
